@@ -11,7 +11,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<UserAgentChanger>("MicroBAgentSwitcher", 1, 0, "UserAgentChanger");
 
     QmlApplicationViewer viewer;
-    viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
+    viewer.setOrientation(QmlApplicationViewer::ScreenOrientationLockLandscape);
     viewer.setMainQmlFile(QLatin1String("qml/main.qml"));
     viewer.showFullScreen();
 
